* Install node 0.4.x and [npm 1.x](http://npmjs.org/)
* Create a package.json file by typing `npm init`
* Add `bones` as a dependency (or clone it to `./node_modules/bones` for development
* In your `index.js` file, add:

        #!/usr/bin/env node
        require('bones').load(__dirname);

        if (!module.parent) {
            require('bones').start();
        }

### Application layout

Bones expect you to organize your application in a certain way, and treats a few directories in special ways.

* `/models` – Backbone models
* `/views` – Backbone views
* `/controllers` – Backbone controllers
* `/templates` – Templates
* `/commands` – CLI commands
* `/routers` – Server only routes
* `/servers` – Server instances

With the exception of `/templates/`, these directories will be populated with `.bones` files. These files have a couple of variables predefined that you can just use, otherwise they are regular files containing JavaScript code. This allows Bones to easily send the same file to the client as well..

Files in each of these directories are expected to provide a single model/view/controller/template etc. The file should be named as the class is name, capitalization is important! A `BlogPost` model should be defined in a `BlogPost.bones` file.

See https://github.com/developmentseed/skeleton for an example app using that layout.

### Creating a server

Bones won't load new files automatically, you need to tell Bones to do that. Create a server by adding a file named `Main.bones` to the servers directory containing `server = Bones.Server.extend()`. This tells bones that your application has a server named *Main*. Each Bones application can have multiple servers. Most of the time though, you'll only need one. You can view all predefined variables available in a `servers/*.bones` file, by looking at the [prefix header](https://github.com/developmentseed/bones/blob/master/server/server.prefix.js) for that file type.

In a `.bones` file, you have to assign the objects you create to a variable named `server`/`model`/`view`/`controller` etc., corresponding to the type of the object. This variable is automatically exported and made available to other `.bones` files.

By default, a server will automatically add all models/views/controllers/routers defined in your application or any of the child plugins it uses. If you only want to have a certain subset of models/views/controllers/routers associated with a particular server or if you want to pass additional configuration options, you have to redefine the `initialize` method:

```javascript
server = Bones.Server.extend({
    initialize: function() {
        controllers['Home'].register(this);
        templates['Home'].register(this);
        views['Home'].register(this);
    }
});
```

To execute additional middleware before any specific routes are bound, you can also override the `middleware` method:

```javascript
server.augment({
    middleware: function(parent, plugin) {
        parent.call(this, plugin);
        routers['Auth'].register(this, {
            secret: plugin.config.secret
        });
    }
});
```

The `.augment` method is an easy way to override an existing function on an object. Defining it works very similar to using Backbone's `.extend`, except that the first parameter is the previous function of that name. `.augment` also concatenates arrays and clones/extends hashes.

### Starting the server

After making your `index.js` file executable, just run the file. Your server should be available at http://localhost:3000. However, since you haven't added any other files yet, most paths will return a 404 page.

### Adding a controller

Unlike Ruby on Rails, Backbone application typically have just one controller that contains all the routes for the application. Start by creating a file named *Default.bones* in your module's `controller` directory:

```javascript
controller = Backbone.Controller.extend({
    routes: {
        '/': home
    },

    home: function() {
        if (Bones.server) {
            // This code is executed on the server.
            this.res.send('10 HOME<br>20 SWEET<br>30 GOTO 10');
        } else {
            // This code is executed on the client.
            // Do nothing.
        }
    }
});
```

When you restart your server, and go to http://localhost:3000, you should see the return message of the controller. When running on the server, the `this` context of a controller callback contains `req` and `req`. To determine whether you're on the server or on the client, you can use `Bones.server`.

> **NOTE**: All code in `*.bones` files is sent to client, so make sure you don't have critical information in them. For code that is strictly server side, you can create files named `*.server.bones`. Those files will never be sent to the client and are only executed on the server, in addition to the regular file if it exists.
